Changelog
=========


1.0.0a4 (2026-01-21)
--------------------

- Apply monkeypatch only with ZCatalog < 6.4 [mamico]
- Fix edge cases with not plain query operators [mamico]


1.0.0a3 (2022-08-04)
--------------------

- Fix catalog plan for query with operators https://github.com/zopefoundation/Products.ZCatalog/pull/139


1.0.0a2 (2022-07-20)
--------------------

- avoid to have Products.DateRecurringIndex.index.DateRecurringIndex between the valueindexes


1.0.0a1 (2022-07-18)
--------------------

- fix plan for unused index in a query https://github.com/zopefoundation/Products.ZCatalog/pull/138
